/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxInterceptorInterceptorsVisitor.java 450 2006-05-12 15:30:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.annotations.analyzer;

import org.objectweb.asm.Type;

import org.objectweb.easybeans.deployment.annotations.impl.JInterceptors;
import org.objectweb.easybeans.deployment.annotations.metadata.interfaces.IEJBInterceptors;

/**
 * This class manages the handling of &#64;{@link javax.interceptor.Interceptors}
 * annotation. This can be applied on a Class or on Methods.
 * @param <T> An implementation of IEJBInterceptors interface.
 * @author Florent Benoit
 */
public class JavaxInterceptorInterceptorsVisitor<T extends IEJBInterceptors> extends
        ObjectArrayAnnotationVisitor<T, Type> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/interceptor/Interceptors;";

    /**
     * Constructor.
     * @param annotationMetadata linked to a class/method metadata.
     */
    public JavaxInterceptorInterceptorsVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits the end of the annotation.<br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        JInterceptors jInterceptors = new JInterceptors();
        for (Type s : getArrayObjects()) {
            jInterceptors.addClass(s.getInternalName());
        }

        getAnnotationMetadata().setAnnotationsInterceptors(jInterceptors);

    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
