/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EnvEntry.java 122 2006-03-05 19:54:41Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.xml.struct.common;

import java.util.ArrayList;
import java.util.List;

/**
 * This class defines the &lt;method&gt; element.
 * @author Florent Benoit
 */
public class MethodDD {

    /**
     * Name of the method.
     */
    private String name = null;

    /**
     * List of params.
     */
    private List<String> params = null;

    /**
     * Default constructor.
     */
    public MethodDD() {
        this.params = new ArrayList<String>();
    }

    /**
     * Gets the name of the method.
     * @return the method's name.
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the name of the method.
     * @param name the name of the method.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Gets the params of this method.
     * @return the method's name.
     */
    public List<String> getParams() {
        return params;
    }

    /**
     * Add a param for this method.
     * @param param the given parameter of the method
     */
    public void addParam(final String param) {
        params.add(param);
    }

}
